@@ -81,6 +81,15 @@ def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, mem
     # point to.  (They're probably unchanged, but ya never know.)
     stdio_isatty = all(os.isatty(fd) for fd in [0, 1, 2])
 
+    # The getuid()/getgid() functions are documented to be only available on
+    # Unix systems, not, for example, Windows.
+    #
+    # We use this weird getattr() construction in order to appease Mypy, which
+    # otherwise has trouble with platform-specific attributes on the "os"
+    # module.
+    uid = getattr(os, "getuid", lambda: None)()
+    gid = getattr(os, "getgid", lambda: None)()
+
     return exec_or_return([
         "docker", "run",
         "--rm",             # Remove the ephemeral container after exiting
@@ -106,9 +115,7 @@ def run(opts, argv, working_volume = None, extra_env = {}, cpus: int = None, mem
 
         # On Unix (POSIX) systems, run the process in the container with the same
         # UID/GID so that file ownership is correct in the bind mount directories.
-        # The getuid()/getgid() functions are documented to be only available on
-        # Unix systems, not, for example, Windows.
-        *(["--user=%d:%d" % (os.getuid(), os.getgid())] if os.name == "posix" else []),
+        *(["--user=%d:%d" % (uid, gid)] if uid and gid else []),
 
         # Map directories to bind mount into the container.
         *["--volume=%s:/nextstrain/%s" % (resolve_path(v.src), v.name)
